<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <meta name="description" content="Backend.AI Console">
  <meta http-equiv="X-UA-Compatible" content="ie=edge">
  <meta name="theme-color" content="#fff">
  <link rel="icon" href="manifest/favicon.ico">
  <link rel="apple-touch-icon" sizes="256x256" href="manifest/backend-ai.iconset/icon_256x256@2x.png">
  <link rel="icon" type="image/png" sizes="32x32" href="manifest/backend-ai.iconset/icon_32x32@1x.png">
  <link rel="icon" type="image/png" sizes="16x16" href="manifest/backend-ai.iconset/icon_16x16@1x.png">
  <link rel="manifest" href="manifest.json">
  <link rel="stylesheet" href="resources/fonts/fonts.css">
  <link rel="stylesheet" href="resources/custom.css">
  <base href="">
  <script src="manifest/app.js"></script>
  <title>Backend.AI</title>
  <script src="./src/lib/webcomponents-loader.js"></script>
  <script src="./src/lib/web-animations-js/web-animations-next-lite.min.js"></script>

  <script>
    globalThis.isElectron = isElectron();
    globalThis.enableSW = true;

    globalThis.process = {env: {NODE_ENV: 'production'}};
    globalThis.packageVersion = "20.07.0";
    globalThis.buildVersion = "200701.200727";
  </script>
  <style>
    body {
      margin: 0;
      font-family: 'Quicksand', Roboto, sans-serif;
      background-color: rgba(255, 255, 255, 1);
      background-image: url("resources/images/loading-background-large.jpg");
      background-repeat: no-repeat;
      background-attachment: fixed;
      background-position: top left;
    }

    .splash {
      position: absolute;
      top: calc(50% - 200px);
      left: calc(50% - 170px);
      width: 340px;
      height: 400px;
      border: 1px solid #aaaaaa;
      border-radius: 4px;
      background-color: #ffffff;
      box-shadow: 0px 0px 3px 3px rgba(0, 0, 0, 0.2);
    }

    .splash-header {
      width: 340px;
      height: 120px;
      background-size: contain;
      background-repeat: no-repeat;
      background-position: left top;
      background-color: RGB(246, 253, 247);
      font-size: 28px;
      font-weight: 400;
      line-height: 60px;
    }

    .splash-header .header-ribbon {
      font-size: 16px;
      line-height: 24px;
      width: 100%;
      background-color: #3e872d;
      color: #ffffff;
      text-align: center;
    }

    ul {
      list-style-type: none;
      padding-left: 20px;
    }

    .splash-information .title {
      font-size: 24px;
      text-align: center;
    }

    .splash-information .detail {
      font-weight: 400;
      font-size: 13px;
    }

    .splash-information p {
      padding: 5px 20px 1px 20px;
    }

    .loading-message {
      position: absolute;
      top: calc(50% + 168px);
      left: calc(50% - 145px);
      width: 300px;
      text-align: center;
      font-size: 16px;
    }

    .sk-folding-cube {
      margin: 20px auto;
      width: 15px;
      height: 15px;
      position: absolute;
      top: calc(50% + 170px);
      left: calc(50% - 130px);
      margin: auto;
      -webkit-transform: rotateZ(45deg);
      transform: rotateZ(45deg);
    }

    .sk-folding-cube .sk-cube {
      float: left;
      width: 50%;
      height: 50%;
      position: relative;
      -webkit-transform: scale(1.1);
      -ms-transform: scale(1.1);
      transform: scale(1.1);
    }

    .sk-folding-cube .sk-cube:before {
      content: '';
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background-color: #3e872d;
      -webkit-animation: sk-foldCubeAngle 2.4s infinite linear both;
      animation: sk-foldCubeAngle 2.4s infinite linear both;
      -webkit-transform-origin: 100% 100%;
      -ms-transform-origin: 100% 100%;
      transform-origin: 100% 100%;
    }

    .sk-folding-cube .sk-cube2 {
      -webkit-transform: scale(1.1) rotateZ(90deg);
      transform: scale(1.1) rotateZ(90deg);
    }

    .sk-folding-cube .sk-cube3 {
      -webkit-transform: scale(1.1) rotateZ(180deg);
      transform: scale(1.1) rotateZ(180deg);
    }

    .sk-folding-cube .sk-cube4 {
      -webkit-transform: scale(1.1) rotateZ(270deg);
      transform: scale(1.1) rotateZ(270deg);
    }

    .sk-folding-cube .sk-cube2:before {
      -webkit-animation-delay: 0.3s;
      animation-delay: 0.3s;
    }

    .sk-folding-cube .sk-cube3:before {
      -webkit-animation-delay: 0.6s;
      animation-delay: 0.6s;
    }

    .sk-folding-cube .sk-cube4:before {
      -webkit-animation-delay: 0.9s;
      animation-delay: 0.9s;
    }

    @-webkit-keyframes sk-foldCubeAngle {
      0%, 10% {
        -webkit-transform: perspective(140px) rotateX(-180deg);
        transform: perspective(140px) rotateX(-180deg);
        opacity: 0;
      }
      25%, 75% {
        -webkit-transform: perspective(140px) rotateX(0deg);
        transform: perspective(140px) rotateX(0deg);
        opacity: 1;
      }
      90%, 100% {
        -webkit-transform: perspective(140px) rotateY(180deg);
        transform: perspective(140px) rotateY(180deg);
        opacity: 0;
      }
    }

    @keyframes sk-foldCubeAngle {
      0%, 10% {
        -webkit-transform: perspective(140px) rotateX(-180deg);
        transform: perspective(140px) rotateX(-180deg);
        opacity: 0;
      }
      25%, 75% {
        -webkit-transform: perspective(140px) rotateX(0deg);
        transform: perspective(140px) rotateX(0deg);
        opacity: 1;
      }
      90%, 100% {
        -webkit-transform: perspective(140px) rotateY(180deg);
        transform: perspective(140px) rotateY(180deg);
        opacity: 0;
      }
    }

    .copyright {
      font-size: 14px;
      text-align: center;
    }
  </style>
</head>

<body>
<div class="splash">
  <div class="splash-header">
    <div class="header-ribbon">Scheduled maintenance</div>
    <img src="manifest/backend.ai-text.svg" style="height:50px;padding:35px 20px;">
  </div>
  <div class="splash-information">
    <h1 class="title">We’ll be back soon!</h1>
    <p>Sorry for the inconvenience but we’re performing some maintenance at the moment.</p>
    <p>If you need to you can always contact us, otherwise we’ll be back online shortly!</p>
    <div class="copyright">Copyright &copy; 2015-2020 Lablup Inc.</div>
  </div>
  <div class="sk-folding-cube">
    <div class="sk-cube1 sk-cube"></div>
    <div class="sk-cube2 sk-cube"></div>
    <div class="sk-cube4 sk-cube"></div>
    <div class="sk-cube3 sk-cube"></div>
  </div>
  <div id="loading-message" class="loading-message">Now under maintenance...</div>
</div>
<noscript>
  <p>Could not render Backend.AI console. Check that JavaScript is enabled.</p>
</noscript>
</body>
</html>
